@@ -229,6 +229,21 @@ setMethod("dbWriteTable", c("SQLiteConnection", "character", "character"),
   }
 )
 
+#' @rdname SQLiteConnection-class
+#' @export
+setMethod("dbAppendTable", "SQLiteConnection", function(conn, name, value, ...,
+                                                        row.names = NULL) {
+  dbBegin(conn, name = "dbAppendTable")
+  on.exit(dbRollback(conn, name = "dbAppendTable"))
+
+  out <- callNextMethod()
+
+  on.exit(NULL)
+  dbCommit(conn, name = "dbAppendTable")
+
+  out
+})
+
 #' @rdname SQLiteConnection-class
 #' @export
 setMethod("sqlData", "SQLiteConnection", function(con, value,
@@ -391,19 +406,6 @@ sqliteListTablesQuery <- function(conn, schema = NULL, name = NULL) {
   ))
 }
 
-#' @rdname SQLiteConnection-class
-#' @export
-setMethod("dbListFields", c("SQLiteConnection", "character"),
-  function(conn, name, ...) {
-    rs <- dbSendQuery(conn, paste("SELECT * FROM ",
-                                  dbQuoteIdentifier(conn, name), "LIMIT 0"))
-    on.exit(dbClearResult(rs))
-
-    names(dbFetch(rs, n = 0, row.names = FALSE))
-  }
-)
-
-
 #' @rdname SQLiteConnection-class
 #' @export
 setMethod("dbDataType", "SQLiteConnection", function(dbObj, obj, ...) {
